@@ -1,12 +1,11 @@
 import functools
-from asyncio import get_event_loop
 from typing import Any, Callable, List, Optional, Tuple, TypeVar
 
 from prompt_toolkit.application import Application
 from prompt_toolkit.application.current import get_app
 from prompt_toolkit.buffer import Buffer
 from prompt_toolkit.completion import Completer
-from prompt_toolkit.eventloop import run_in_executor_with_context
+from prompt_toolkit.eventloop import get_event_loop, run_in_executor_with_context
 from prompt_toolkit.filters import FilterOrBool
 from prompt_toolkit.formatted_text import AnyFormattedText
 from prompt_toolkit.key_binding.bindings.focus import focus_next, focus_previous
@@ -264,7 +263,7 @@ def progress_dialog(
         focusable=False,
         # Prefer this text area as big as possible, to avoid having a window
         # that keeps resizing when we add text to it.
-        height=D(preferred=10 ** 10),
+        height=D(preferred=10**10),
     )
 
     dialog = Dialog(
